@@ -13,6 +13,7 @@ import getpass
 import mimetypes
 import requests
 import hashlib
+import time
 
 from pkg_resources import get_distribution
 from pkg_resources import DistributionNotFound
@@ -430,7 +431,17 @@ class SbSession:
             mimetype = self._guess_mimetype(filename)
             response = self._sbSessionEx.upload_cloud_file_upload_session(itemid, filename, mimetype)
             if 'data' in response and 'completeMultiPartUpload' in response['data'] and 'Successful' in response['data']['completeMultiPartUpload']:
-                ret = self.get_item(itemid)
+                path_on_disk = ""
+                while path_on_disk == "":
+                    ret = self.get_item(itemid)
+                    time.sleep(3)
+                    print("Completing upload...Please wait.")
+                    if 'files' in ret:
+                        for f in ret['files']:
+                            if 'name' in f:
+                                if f['name'] == filename:
+                                    if 'pathOnDisk' in f:
+                                        path_on_disk = f['pathOnDisk']
             else:
                 raise Exception('Cloud upload failed for', filename)
         return ret
@@ -1273,115 +1284,55 @@ class SbSession:
         """
         return self._update_acls(self.ACL_REMOVE, self.ACL_WRITE, "ROLE:%s" % role_name, item_id)
 
+    def publish_to_public_bucket(self, item_id):
+        """ call publish end point from catalog
+            this should publish all files to public s3 publish bucket
+            TODO: Fix documentation
+        """
+        return self._session.post(self._base_item_url + item_id + "/publishFilesToS3")
+
     def publish_array_to_public_bucket(self, item_id, filenames):
-        """publish a list of files on an item from the public s3 publish bucket
+        """ publish a list of files on an item to the public s3 publish bucket
 
         :param item_id: The ID of the ScienceBase item
-        :param filenames: a list of filenames to be unpublished
+        :param filenames: a list of filenames to be published
         """
-        if not self._sbSessionEx.is_logged_in():
-            print(f'{self._username} not logged into Keycloak -- cloud services not available')
-        else:
+        for filename in filenames:
             item = self.get_item(item_id)
+            pathOnDisk = ""
+            cuid = ""
 
-            for filename in filenames:
-                cuid = ""
-                key = ""
-                pathOnDisk = ""
+            if 'files' in item:
+                for f in item['files']:
+                    if 'name' in f:
+                        if f['name'] == filename:
+                            if 'pathOnDisk' in f:
+                                pathOnDisk = f['pathOnDisk']
+                            if 'cuid' in f:
+                                cuid = f['cuid']
+                            break
+            if pathOnDisk == "":
+                if 'facets' in item:
+                    for facet in item['facets']:
+                        if 'files' in facet:
+                            for f in facet['files']:
+                                if f['name'] == filename:
+                                    if 'pathOnDisk' in f:
+                                        pathOnDisk = f['pathOnDisk']
+                                    if 'cuid' in f:
+                                        cuid = f['cuid']
+                                    break
 
-                if 'files' in item:
-                    for f in item['files']:
-                        if 'name' in f:
-                            if f['name'] == filename:
-                                if 'pathOnDisk' in f:
-                                    pathOnDisk = f['pathOnDisk']
-                                if 'cuid' in f:
-                                    cuid = f['cuid']
-                                if 'key' in f:
-                                    key = f['key']
-                                break
+            input = {"itemId": item_id, "filename": filename, "action": "publish", "pathOnDisk": pathOnDisk}
 
-                if cuid == "":
-                    if 'facets' in item:
-                        for facet in item['facets']:
-                            if 'files' in facet:
-                                for f in facet['files']:
-                                    if f['name'] == filename:
-                                        if 'pathOnDisk' in f:
-                                            pathOnDisk = f['pathOnDisk']
-                                        if 'cuid' in f:
-                                            cuid = f['cuid']
-                                        if 'key' in f:
-                                            key = f['key']
-                                        break
-                    
-                if cuid is None:
-                    cuid = ""
+            response = self._sbSessionEx.publish_to_public_bucket(input)
 
-                input = {"itemId": item_id, "filename": filename, "action": "publish", "pathOnDisk": pathOnDisk}
+            print(response)
 
-                response = self._sbSessionEx.publish_to_public_bucket(input)
-                print(response)
-                if response:
-                    print("Successfully published filename " + filename + " from public S3 bucket")
-                else:
-                    print("Failed to publish file " + filename + " from public S3 bucket")
-
-
-    # def publish_to_public_bucket(self, item_id):
-    #     """ call publish end point from catalog
-    #         this should publish all files to public s3 publish bucket
-    #         TODO: Fix documentation
-    #     """
-    #     return self._session.post(self._base_item_url + item_id + "/publishFilesToS3")
-
-    # def publish_array_to_public_bucket(self, item_id, filenames):
-    #     """ publish a list of files on an item to the public s3 publish bucket
-
-    #     :param item_id: The ID of the ScienceBase item
-    #     :param filenames: a list of filenames to be published
-    #     """
-    #     for filename in filenames:
-    #         item = self.get_item(item_id)
-    #         pathOnDisk = ""
-    #         cuid = ""
-
-    #         if 'files' in item:
-    #             for f in item['files']:
-    #                 if 'name' in f:
-    #                     if f['name'] == filename:
-    #                         if 'pathOnDisk' in f:
-    #                             pathOnDisk = f['pathOnDisk']
-    #                         if 'cuid' in f:
-    #                             cuid = f['cuid']
-    #                         break
-    #         if pathOnDisk == "":
-    #             if 'facets' in item:
-    #                 for facet in item['facets']:
-    #                     if 'files' in facet:
-    #                         for f in facet['files']:
-    #                             if f['name'] == filename:
-    #                                 if 'pathOnDisk' in f:
-    #                                     pathOnDisk = f['pathOnDisk']
-    #                                 if 'cuid' in f:
-    #                                     cuid = f['cuid']
-    #                                 break
-
-    #         publishDict = {
-    #             "filename": filename,
-    #             "actionValue": "publish",
-    #             "cuid": cuid,
-    #             "pathOnDisk": pathOnDisk
-    #         }
-
-    #         response = self._session.post(self._base_item_url + item_id + "/publishSingleFileToS3",
-    #                                       data=json.dumps(publishDict))
-    #         print(response)
-
-    #         if response:
-    #             print("Successfully published filename " + filename + " to public S3 bucket")
-    #         else:
-    #             print("Failed to publish file " + filename + " to public S3 bucket")
+            if response:
+                print("Successfully published filename " + filename + " to public S3 bucket")
+            else:
+                print("Failed to publish file " + filename + " to public S3 bucket")
 
     def unpublish_array_from_public_bucket(self, item_id, filenames):
         """unpublish a list of files on an item from the public s3 publish bucket
